@@ -50,3 +50,6 @@ HEART_BEAT_INTERVAL = 10
 
 # Name prefix for internal diagnostic metrics for Wavefront SDKs.
 SDK_METRIC_PREFIX = '~sdk.python'
+
+# Tag key for span logs.
+SPAN_LOG_KEY = "_spanLogs"
